__version__ = "0.2.5"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(detached from v0.2.5)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '8dabc80a2519f109285d3dc467ecad1eb3e0370d'
__git_head_subject__ = 'Finished release v0.2.5.'
__git_head_message__ = ''
__git_dirty_diff__ = ''